<?php
/**
 * Aqua Page Builder functions
 *
 * This holds the external functions which can be used by the theme
 * Requires the AQ_Page_Builder class
 *
 * @todo - multicheck, image checkbox, better colorpicker
**/

if(class_exists('AQ_Page_Builder')) {
	
	/** 
	 * Core functions
	*******************/
	 
	/* Register a block */
	function aq_register_block($block_class) {
		global $aq_registered_blocks;
		$aq_registered_blocks[strtolower($block_class)] = new $block_class;
	}
	
	
	/** Un-register a block **/
	function aq_unregister_block($block_class) {
		global $aq_registered_blocks;
		$block_class = strtolower($block_class);
		foreach($aq_registered_blocks as $block) {
			if($block->id_base == $block_class) unset($aq_registered_blocks[$block_class]);
		}
	}
	
	/** Get list of all blocks **/
	function aq_get_blocks($template_id) {
		global $aq_page_builder;
		$blocks = $aq_page_builder->get_blocks($template_id);
		
		return $blocks;
	}
	
	/** 
	 * Form Field Helper functions
	 *
	 * Provides some default fields for use in the blocks
	 *
	 * @todo build this into a separate class instead!
	********************************************************/
	
	/* Input field - Options: $size = min, small, full */
	function aq_field_input($field_id, $block_id, $input, $size = 'full', $type = 'text') {
		$output = '<input type="'.$type.'" id="'. $block_id .'_'.$field_id.'" class="input-'.$size.'" value="'.$input.'" name="aq_blocks['.$block_id.']['.$field_id.']">';
		
		return $output;
	}
	
	/* Textarea field */
	function aq_field_textarea($field_id, $block_id, $text, $size = 'full') {
		$output = '<textarea id="'. $block_id .'_'.$field_id.'" class="textarea-'.$size.'" name="aq_blocks['.$block_id.']['.$field_id.']" rows="5">'.$text.'</textarea>';
		
		return $output;
	}
	
	
	/* Select field */
	function aq_field_select($field_id, $block_id, $options, $selected) {
		$options = is_array($options) ? $options : array();
		$output = '<select id="'. $block_id .'_'.$field_id.'" name="aq_blocks['.$block_id.']['.$field_id.']">';
		foreach($options as $key=>$value) {
			$output .= '<option value="'.$key.'" '.selected( $selected, $key, false ).'>'.htmlspecialchars($value).'</option>';
		}
		$output .= '</select>';
		
		return $output;
	}
	
	/* Multiselect field */
	function aq_field_multiselect($field_id, $block_id, $options, $selected_keys = array()) {
		$output = '<select id="'. $block_id .'_'.$field_id.'" multiple="multiple" class="select of-input" name="aq_blocks['.$block_id.']['.$field_id.'][]">';
		foreach ($options as $key => $option) {
			$selected = (is_array($selected_keys) && in_array($key, $selected_keys)) ? $selected = 'selected="selected"' : '';			
			$output .= '<option id="'. $block_id .'_'.$field_id.'_'. $key .'" value="'.$key.'" '. $selected .' />'.$option.'</option>';
		}
		$output .= '</select>';
		
		return $output;
	}
	
	/* Color picker field */
	function aq_field_color_picker($field_id, $block_id, $color) {
		$output = '<div class="aqpb-color-picker">';
			$output .= '<input type="text" id="'. $block_id .'_'.$field_id.'" class="input-color-picker" value="'. $color .'" name="aq_blocks['.$block_id.']['.$field_id.']" />';
			$output .= '<div class="cw-color-picker" rel="'. $block_id .'_'.$field_id.'"></div>';
		$output .= '</div>';
		
		return $output;
	}
	
	/* Single Checkbox */
	function aq_field_checkbox($field_id, $block_id, $check) {
		$output = '<input type="hidden" name="aq_blocks['.$block_id.']['.$field_id.']" value="0" />';
		$output .= '<input type="checkbox" id="'. $block_id .'_'.$field_id.'" class="input-checkbox" name="aq_blocks['.$block_id.']['.$field_id.']" '. checked( 1, $check, false ) .' value="1"/>';
		
		return $output;
	}
	
	/* Multi Checkbox */
	function aq_field_multicheck($field_id, $block_id, $fields = array(), $selected = array()) {
	
	}
	
	/* Media Uploader */
	function aq_field_upload($field_id, $block_id, $media, $media_type = 'img') {
		$output = '<input type="text" id="'. $block_id .'_'.$field_id.'" class="input-full input-upload" value="'.$media.'" name="aq_blocks['.$block_id.']['.$field_id.']">';
		$output .= '<a href="#" class="aq_upload_button button" rel="'.$media_type.'">Upload</a><p></p>';
		
		return $output;
	}
	
	/** 
	 * Misc Helper Functions
	**************************/
	
	/** Get column width
	 * @parameters - $size (column size), $grid (grid size e.g 940), $margin
	 */
	function aq_get_column_width($size, $grid = 940, $margin = 20) {
		
		$columns = range(1,12);
		$widths = array();
		foreach($columns as $column) {
			$width = (( $grid + $margin ) / 12 * $column) - $margin;
			$width = round($width);
			$widths[$column] = $width;
		}
		
		$column_id = absint(preg_replace("/[^0-9]/", '', $size));
		$column_width = $widths[$column_id];
		return $column_width;
	}
	
	/** Recursive sanitize
	 * For those complex multidim arrays 
	 * Has impact on server load on template save, so use only where necessary 
	 */
	function aq_recursive_sanitize($value) {
		if(is_array($value)) {
			$value = array_map('aq_recursive_sanitize', $value);
		} else {
			$value = htmlspecialchars(stripslashes($value));
			
			$value = preg_replace('/\s\s+/', ' ', $value);
		}
		return $value;
	}
	
}


function c5_get_shortcode_doc() {

//...

$shortcode = $_POST['shortcode'];

$atts =code125_shortcodes($shortcode);

$data = $atts['documentation'];   
   echo $data;
   
   $attirbutes = $atts['atts'];
   if( is_array($attirbutes) ){
   		foreach ($attirbutes as $key => $value) {
   			echo  '<h4>'.$value['desc'] . '</h4><div style="padding-left:50px;">' .  $value['documentation'] . '</div>';
   		}
   
   }
	die();
}
add_action('wp_ajax_nopriv_c5_get_shortcode_doc', 'c5_get_shortcode_doc');
add_action('wp_ajax_c5_get_shortcode_doc', 'c5_get_shortcode_doc');

function c5_get_page_builder_docs($atts,$content) {
	$docs = '<h3>Section 1.1 Introduction</h3>
	Page builder is used for creating new template pages. It consists of three parts; the first part contains the page elements and the layout elements. the page elements part contains tabs such as layout, elements, tabs, sliders, article, posts, social and advertisements. those tabs are used in layout elements\' part. for each item in each tab of the page elements, there is a question mark icon, by clicking it, documentation of this item is displayed.
	
	The layout elements part contains elements\' columns that are used for dividing the page into one or more columns.
	
	The other third part of page builder is a block that contains template options such as: add new template, delete template or update template.
	<h3>Section 1.2 Add New Template</h3>
	<b>In the previous section, Page Builder parts have been defined, so in this section new template page will be created using Page Builder. This template page will include three columns; the first column will include posts, the second one will include title and the third one will include normal text. So in order to create this template page, the following steps are needed:</b>
	<ol>
		<li><span style="font-size: 1em;">From "Admin Menu", click on "Appearance", <br/><img src="http://d.pr/i/1dCz+"/></span></li>
		<li><span style="font-size: 1em;">From "Appearance", click on "Page Builder" item, <br/><img src="http://d.pr/i/uGAL+"/></span></li>
		<li><span style="font-size: 1em;">From "Page Builder", select "Add New Template" tab, <br/><img src="http://d.pr/i/1uTS+"/></span></li>
		<li><span style="font-size: 1em;">From "Add New Template", type the name of your template you need to create, for example "My Template", then click "Create Template" button, <br/><img src="http://d.pr/i/DkVo+"/></span></li>
		<li><span style="font-size: 1em;">Drag and drop the icon "1/3 Column" from "Layout Elements", <br/><img src="http://d.pr/i/nigZ, empty template page, <br/><img src="http://d.pr/i/HIDu, then it will be displayed as shown, <br/><img src="http://d.pr/i/3hBz+"/></span></li>
		<li><span style="font-size: 1em;">Repeat step 5 to add second and third columns "1/3 Column", then it will be displayed as shown, <br/><img src="http://d.pr/i/cF8B+"/></span></li>
		<li><span style="font-size: 1em;">After dividing template page into three parts, in order to display posts of your website in the first column, from "Page Elements" select "Posts" tab, <br/><img src="http://d.pr/i/C2Xo+"/>, then drag and drop "Posts" item into the first column, <br/><img src="http://d.pr/i/qLTA+"/>, there is a small arrow in "Posts" item, you can click it to appear / disappear the content of "Posts" item, <br/><img src="http://d.pr/i/7vJn+"/></span></li>
		<li><span style="font-size: 1em;">In order to add "Title" item in the second column, from "Page Elements" select "Elements" tab, <br/><img src="http://d.pr/i/lE20+"/>, drag and drop "Title" item into the second column and write under "Title Label" your title, for example "Blog Title", <br/><img src="http://d.pr/i/tPNs+"/>, there is a small arrow in posts item, you can click it to appear / disappear the content of "Title" item, <br/><img src="http://d.pr/i/XeDx+"/></span></li>
		<li><span style="font-size: 1em;">In order to add "Text" item in the third column, from "Page Elements" select "Text" tab, <br/><img src="http://d.pr/i/lE20+"/>, drag and drop "Text" item into the second column and write under "Content Label" your text, for example "Hello World", <br/><img src="http://d.pr/i/q318+"/>, there is a small arrow in "Text" item, You can click it to appear / disappear the content of posts-slider item, <br/><img src="http://d.pr/i/Ksw4+"/></span></li>
	</ol>
	<h3>Section 1.3 Add Template to Page</h3>
	<b>In the previous section, a new template page has been created, in this section, you can add this template to a certain page of your website, the following steps are needed:</b>
	<ol>
		<li><span style="font-size: 1em;">From "Admin" navigation menu, click "Pages", <br/><img src="http://d.pr/i/1dCz+"/></span></li>
		<li><span style="font-size: 1em;">From "Pages", click "Add New" menu, <br/><img src="http://d.pr/i/qdFs+"/></span></li>
		<li><span style="font-size: 1em;">Insert the title of the page, for example "Template page", <br/><img src="http://d.pr/i/clup+"/></span></li>
		<li><span style="font-size: 1em;">From "Page Options", select "Yes" from "Layout Builder" and "My Template" from templates menu, <br/><img src="http://d.pr/i/IQ9g+"/></span></li>
		<li><span style="font-size: 1em;">Click "Publish" button, <br/><img src="http://d.pr/i/dXBa+"/></span></li>
		<li><span style="font-size: 1em;">Click "View Page" button, <br/><img src="http://d.pr/i/CIHl+"/></span></li>
	</ol>
	<b>Now, you can display the content and template page on your website.</b>
	<h3>Section 1.4 Update Template</h3>
	<b>In the previous section, a template has been added to a certain page of your website. In this section, you can update one part of the template page, for example: the content of the third column, the following steps are needed:</b>
	<ol>
		<li><span style="font-size: 1em;">From "Admin" navigation menu, click "Appearance", <br/><img src="http://d.pr/i/1dCz+"/></span></li>
		<li><span style="font-size: 1em;">From "Appearance", click "Page Builder" item, <br/><img src="http://d.pr/i/uGAL+"/></span></li>
		<li><span style="font-size: 1em;">Select "My Template" from the tabs of templates, <br/><img src="http://d.pr/i/1es7+"/></span></li>
		<li><span style="font-size: 1em;">Go to third column, click the arrow of "Text" item, <br/><img src="http://d.pr/i/q318+"/></span></li>
		<li><span style="font-size: 1em;">Below "Content", type "Hello there again", <br/><img src="http://d.pr/i/5EsX+"/></span></li>
		<li><span style="font-size: 1em;">Update the template by clicking "Update Template", <br/><img src="http://d.pr/i/Kp6u+"/></span></li>
	</ol>
	<b>By refreshing the page, the content is updated.</b>
	<h3>Section 1.5 Duplicated Template Page</h3>
	<b>In section 1.2, a new template page has been created, so in this section you can duplicate this template and add "Today" element to the second column of the duplicated template page, the following steps are needed:</b>
	<ol>
		<li><span style="font-size: 1em;">From "Admin" navigation menu, click "Appearance", <br/><img src="http://d.pr/i/1dCz+"/></span></li>
		<li><span style="font-size: 1em;">From "Appearance", click "Page Builder" item, <br/><img src="http://d.pr/i/uGAL+"/></span></li>
		<li><span style="font-size: 1em;">Select "My Template" from the tabs of templates, <br/><img src="http://d.pr/i/1es7+"/></span></li>
		<li><span style="font-size: 1em;">In order to duplicate the template, click "Duplicate" button, <br/><img src="http://d.pr/i/1es7+"/></span></li>
		<li><span style="font-size: 1em;">Select "My Template" from the tabs of templates and update "Template Name", for example "Duplicate Template", <br/><img src="http://d.pr/i/MpbJ+"/></span></li>
		<li><span style="font-size: 1em;">From "Page Elements" select "Elements" tab, <br/><img src="http://d.pr/i/lE20, drag and drop "Today" item into the second column, <br/><img src="http://d.pr/i/uHaz, there is a small arrow in "Today" item, you can click it to appear / disappear the content of "Today" item, <br/><img src="http://d.pr/i/7RBI+"/></span></li>
		<li><span style="font-size: 1em;">In order to update the template, click "Update Template", <br/><img src="http://d.pr/i/MpbJ+"/></span></li>
	</ol>
	<b>You have duplicated the template page "My Template".</b>
	<h3>Section 1.6 Delete Template</h3>
	<b>In the previous section, the template page "My Template" has been duplicated, so in this section you can delete this template "Duplicated Template", the following steps are needed:</b>
	<ol>
		<li>From "Admin" navigation menu, click "Appearance", <br/><img src="http://d.pr/i/1dCz+"/></li>
		<li>From "Appearance", click "Page Builder" item, <br/><img src="http://d.pr/i/uGAL+"/></li>
		<li>Select "Duplicated Template" from the tabs of templates to delete it, <br/><img src="http://d.pr/i/1es7+"/></li>
		<li>Click "Delete" button <br/><img src="http://d.pr/i/ILNP+"/></li>
		<li>Now, you have deleted it, <br/><img src="http://d.pr/i/cddf+"/></li>
	</ol>';  
	return $docs;
}

add_shortcode('docs_page_builder' , 'c5_get_page_builder_docs');


function c5_page_builder_docs() {
	
	echo c5_get_page_builder_docs();  
   	die();
}
add_action('wp_ajax_nopriv_c5_page_builder_docs', 'c5_page_builder_docs');
add_action('wp_ajax_c5_page_builder_docs', 'c5_page_builder_docs');
?>