<?php
/* Bones Custom Post Type Example
This page walks you through creating 
a custom post type and taxonomies. You
can edit this one or copy the following code 
to create another one. 

I put this in a separate file so as to 
keep it organized. I find it easier to edit
and change things if they are concentrated
in their own file.

Developed by: Eddie Machado
URL: http://themble.com/bones/
*/


// let's create the function for the custom type
function code125_custom_posts_register() { 
	
	
	$custom_posts = ot_get_option('custom_posts', array());
	    if ($custom_posts) {
	        foreach ($custom_posts as $custom_post) {
	           
	            register_post_type( $custom_post['slug'], /* (http://codex.wordpress.org/Function_Reference/register_post_type) */
	             	// let's now add all the options for this post type
	            	array('labels' => array(
	            		'name' => $custom_post['title'], /* This is the Title of the Group */
	            		'singular_name' =>  $custom_post['title'], /* This is the individual type */
	            		'all_items' => __('All '.$custom_post['title'] .' Items', 'code125'), /* the all items menu item */
	            		'add_new' => __('Add New Item', 'code125'), /* The add new menu item */
	            		'add_new_item' => __('Add New '.$custom_post['title'] .' Item', 'code125'), /* Add New Display Title */
	            		'edit' => __( 'Edit', 'code125' ), /* Edit Dialog */
	            		'edit_item' => __('Edit '.$custom_post['title'] .' Item', 'code125'), /* Edit Display Title */
	            		'new_item' => __('New '.$custom_post['title'] .' Item', 'code125'), /* New Display Title */
	            		'view_item' => __('View '.$custom_post['title'] .' Item', 'code125'), /* View Display Title */
	            		'search_items' => __('Search '.$custom_post['title'] .' Items', 'code125'), /* Search Custom Type Title */ 
	            		'not_found' =>  __('Nothing found in the Database.', 'code125'), /* This displays if there are no entries yet */ 
	            		'not_found_in_trash' => __('Nothing found in Trash', 'code125'), /* This displays if there is nothing in the trash */
	            		'parent_item_colon' => ''
	            		), /* end of arrays */
	            		'description' => __( 'This is the example '.$custom_post['title'] , 'code125' ), /* Custom Type Description */
	            		'public' => true,
	            		'publicly_queryable' => true,
	            		'exclude_from_search' => false,
	            		'show_ui' => true,
	            		'query_var' => true,
	            		'menu_position' => 8, /* this is what order you want it to appear in on the left hand side menu */ 
	            		'menu_icon' => get_template_directory_uri() . '/library/images/custom-post-icon.png', /* the icon for the custom post type menu */
	            		'rewrite'	=> array( 'slug' => $custom_post['slug'], 'with_front' => false ), /* you can specify it's url slug */
	            		'has_archive' => 'team', /* you can rename the slug here */
	            		'capability_type' => 'post',
	            		'hierarchical' => false,
	            		'supports' => array( 'title',  'comments' ,'editor', 'thumbnail', 'excerpt'  , 'sticky' , 'post-formats'),
	            		'taxonomies' => array('post_tag')
	             	) /* end of options */
	            ); /* end of register post type */
	            if($custom_post['category']!= ''){
	            register_taxonomy( $custom_post['category'], 
	            	array($custom_post['slug']), /* if you change the name of register_post_type( 'team', then you have to change this */
	            	array('hierarchical' => true,     /* if this is true it acts like categories */             
	            		'labels' => array(
	            			'name' => $custom_post['category_name'], /* name of the custom taxonomy */
	            			'singular_name' =>$custom_post['category_name'], /* single taxonomy name */
	            			'search_items' =>  __( 'Search '.$custom_post['category_name'], 'code125' ), /* search title for taxomony */
	            			'all_items' => __( 'All '.$custom_post['category_name'], 'code125' ), /* all title for taxonomies */
	            			'parent_item' => __( 'Parent '.$custom_post['category_name'], 'code125' ), /* parent title for taxonomy */
	            			'parent_item_colon' => __( 'Parent '.$custom_post['category_name'].':', 'code125' ), /* parent taxonomy title */
	            			'edit_item' => __( 'Edit '.$custom_post['category_name'], 'code125' ), /* edit custom taxonomy title */
	            			'update_item' => __( 'Update '.$custom_post['category_name'], 'code125' ), /* update title for taxonomy */
	            			'add_new_item' => __( 'Add New '.$custom_post['category_name'], 'code125' ), /* add new title for taxonomy */
	            			'new_item_name' => __( 'New '.$custom_post['category_name'].' Name', 'code125' ) /* name title for taxonomy */
	            		),
	            		'show_ui' => true,
	            		'query_var' => true,
	            	)
	            ); 
	            }
	            
	            
	        }
	    }
	
	
} 

	// adding the function to the Wordpress init
	add_action( 'init', 'code125_custom_posts_register');
	
    
      
    
	
	

?>