<?php
/**
 * Initialize the options before anything else. 
 */
add_action( 'admin_init', '_custom_theme_options_custom_posts', 99 );

/**
 * Theme Mode demo code of all the available option types.
 *
 * @return    void
 *
 * @access    private
 * @since     2.0
 */
function _custom_theme_options_custom_posts() {
  
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Create a custom settings array that we pass to 
   * the OptionTree Settings API Class.
   */
  
  
  $new_section = array(
    'title'       => 'Custom Post Types',
    'id'          => 'custom_post'
  );
  array_push($saved_settings['sections'], $new_section);
  
  if(function_exists('c5_get_all_skins_default')){
  	$skins2 = c5_get_all_skins_default();
  }else {
  	$skins2 = array(
  	    array(
  	        'label' => 'Not Supported',
  	        'value' => ''
  	    )
  	);
  }
  
  $new_settings = 
    array(
        'label' => 'Custom Post Types',
        'id' => 'custom_posts',
        'type' => 'list-item',
        'desc' => 'Add New Custom Post Type.',
        'settings' => array(
            array(
                'label' => 'Slug',
                'id' => 'slug',
                'type' => 'text',
                'desc' => 'Add Post type slug, this will be used in the url',
                'std' => '',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
                'label' => 'Category Name',
                'id' => 'category_name',
                'type' => 'text',
                'desc' => 'Add Category name"',
                'std' => 'Category',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => '',
            )
            ,
            array(
                'label' => 'Category slug',
                'id' => 'category',
                'type' => 'text',
                'desc' => 'Add Category to this custom post, add its slug here "this will be used in the url of the category page"',
                'std' => '',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => '',
            ),
            array(
                'label' => 'Posts Skin',
                'id' => 'posts_skin',
                'type' => 'select',
                'desc' => 'Choose Default Posts Skin.',
                'choices' => $skins2,
                'std' => '',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
                'label' => 'Follow Category styling Settings',
                'id' => 'posts_styling',
                'type' => 'select',
                'desc' => 'Follow the article category styling Settings, Default: Yes.',
                'choices' => array(
                    array(
                        'label' => 'Yes',
                        'value' => 'yes'
                    ),
                    array(
                        'label' => 'No',
                        'value' => 'no'
                    )
                ),
                'std' => 'yes',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
              'label'       => 'Posts Meta Data Enable',
              'id'          => 'meta_data',
              'type'        => 'checkbox',
              'desc'        => 'Posts Meta Data Enable or Disable.',
              'choices'     => array(
                array (
                  'label'       => 'Show Single Post Name in Breadcrumbs',
                  'value'       => 'single_crumb'
                ),
                array (
                  'label'       => 'Show Featured Media',
                  'value'       => 'media'
                ),
                array (
                  'label'       => 'Show Social Share count',
                  'value'       => 'social_count'
                ),
                array (
                  'label'       => 'Show Facebook Like Button',
                  'value'       => 'facebook'
                ),
                array (
                  'label'       => 'Show Twitter Button',
                  'value'       => 'twitter'
                ),
                array (
                  'label'       => 'Show Google Plus Button',
                  'value'       => 'gplus'
                ),
                array (
                  'label'       => 'Show Pintrest Button',
                  'value'       => 'pintrest'
                ),
                array (
                  'label'       => 'Show Like Button',
                  'value'       => 'like'
                ),
                array (
                  'label'       => 'Show View Count',
                  'value'       => 'view'
                ),
                array (
                  'label'       => 'Show Author Photo',
                  'value'       => 'author_photo'
                ),
                array (
                  'label'       => 'Show Author Link',
                  'value'       => 'author'
                ),
                array (
                  'label'       => 'Show Author Position',
                  'value'       => 'author_position'
                ),
                array (
                  'label'       => 'Show Date',
                  'value'       => 'date'
                ),
                array (
                  'label'       => 'Show Time',
                  'value'       => 'time'
                ),
                array (
                  'label'       => 'Show Commenets Count',
                  'value'       => 'comments_count'
                ),
                array (
                  'label'       => 'Show Categories',
                  'value'       => 'categpory'
                ),
                array (
                  'label'       => 'Show Tags',
                  'value'       => 'tags'
                ),
                array (
                  'label'       => 'Show Related Posts',
                  'value'       => 'related'
                ),
                array (
                  'label'       => 'Enable Comments Section',
                  'value'       => 'commnets'
                ),
                array (
                  'label'       => 'Enable Facebook Comments',
                  'value'       => 'fb_commnets'
                ),
                array (
                  'label'       => 'Enable WordPress Comments',
                  'value'       => 'wp_commnets'
                )
              ),
              'std'         => array( 'media', 'social_count', 'facebook', 'twitter', 'gplus', 'pintrest', 'like', 'view', 'author_photo', 'author', 'author_position', 'date', 'time', 'comments_count', 'categpory', 'tags', 'related', 'commnets', 'fb_commnets', 'wp_commnets'  ),
              'rows'        => '',
              'post_type'   => '',
              'taxonomy'    => '',
              'class'       => '',
              'section'     => ''
            ),
            array(
                'label' => 'Date Format Posts Type',
                'id' => 'c5_date_format',
                'type' => 'select',
                'desc' => 'Set The Date format "Normal date: 12th January, 2013" or "Ago date: 2 days ago"',
                'choices' => array(
                    array(
                        'label' => 'Normal date',
                        'value' => 'normal'
                    ),
                    array(
                        'label' => 'Ago date',
                        'value' => 'ago'
                    )
                ),
                'std' => 'normal',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => '',
                'section' => 'article'
            ),
            array(
                'label' => 'Related Posts Type',
                'id' => 'related_type',
                'type' => 'select',
                'desc' => 'Select Related Posts selection type based on:',
                'choices' => array(
                    array(
                        'label' => 'Tags',
                        'value' => 'tags'
                    ),
                    array(
                        'label' => 'Category',
                        'value' => 'category'
                    ),
                    array(
                        'label' => 'Random',
                        'value' => 'random'
                    )
                ),
                'std' => 'tags',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
                'label' => 'Before Article Section Content',
                'id' => 'article_before',
                'type' => 'textarea',
                'desc' => 'Add a content to show before each article',
                'std' => '',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
                'label' => 'After Article Section Content',
                'id' => 'article_after',
                'type' => 'textarea',
                'desc' => 'Add a content to show after each article',
                'std' => '',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
                'label' => 'Comments Section Order',
                'id' => 'comments_order',
                'type' => 'select',
                'desc' => 'Select the Comments Order in your article, Default: Facebook - WP Comments',
                'choices' => array(
                    array(
                        'label' => 'Facebook - WP Comments',
                        'value' => 'facebook_comments'
                    ),
                    array(
                        'label' => 'WP Comments - Facebook',
                        'value' => 'comments_facebook'
                    )
                ),
                'std' => 'facebook_comments',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
            array(
                'label' => 'Facebook Color',
                'id' => 'facebook_color',
                'type' => 'select',
                'desc' => 'Select Facebook Color Mode. Default Light.',
                'choices' => array(
                    array(
                        'label' => 'Light',
                        'value' => 'light'
                    ),
                    array(
                        'label' => 'Dark',
                        'value' => 'dark'
                    )
                ),
                'std' => 'light',
                'rows' => '',
                'post_type' => '',
                'taxonomy' => '',
                'class' => ''
            ),
        ),
        'std' => '',
        'rows' => '',
        'post_type' => '',
        'taxonomy' => '',
        'class' => '',
        'section' => 'custom_post'
    );
  
  array_push($saved_settings['settings'], $new_settings);
  
      
      	  
      
  
    
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $saved_settings );
  
  
    update_option( 'option_tree_settings', $saved_settings ); 
    
  
  
}